
"""Compose a string with masculine, feminine, neuter nominative singular of a given particple ofr `lexeme`.
$(SIGNATURES)
"""
function participleslashline(
    lex::LexemeUrn,  
    tense::GMPTense, voice::GMPVoice, 
    kd::Kanones.FilesDataset)
    ptcplforms = filter(f -> f isa GMFParticiple && gmpTense(f) == tense && gmpVoice(f) == voice && gmpNumber(f) == gmpNumber(1) && gmpCase(f) == gmpCase(1), allforms())


    generated = map(f -> generate(lex, formurn(f), kd),  ptcplforms)
    join(map(v -> isempty(v) ? "" : v[1], generated), ", ")

end

"""Compose markdown table with a declension of a single noun.

$(SIGNATURES)
"""
function ptcpldeclension_md(
    lex::LexemeUrn, 
    tense::GMPTense, voice::GMPVoice, 
    kd::Kanones.FilesDataset)
    stemmatches = filter(s -> lexeme(s) == lex, stemsarray(kd))
    if isempty(stemmatches)
        throw(DomainError("No stems found for lexeme $(lex)"))
    elseif length(stemmatches) != 1
        @warn("More than one stem found for $(lex): using first stem.")
    end
    stem = stemmatches[1]
    rules = filter(r ->  r isa ParticipleRule && inflectionclass(r) == inflectionclass(stem) &&gmpTense(r) == tense && gmpVoice(r) == voice, rulesarray(kd))

    labels = ["nominative", "genitive", "dative", "accusative"]
    caselist = map(l -> gmpCase(l), labels)

    lines = [
        "| | Masculine | Feminine | Neuter |", 
        "| --- | --- | --- | --- |",
        "| *singular* |  |  |  |"
    ]
    for i in 1:length(labels)
        mform = ""
        mrules = filter(r -> gmpNumber(r) == gmpNumber("singular") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("masculine"), rules)
        if ! isempty(mrules)
            generated = generate(lex, formurn(mrules[1]),  kd)
            mform = join(generated,", ")
        end

        fform = ""
        frules = filter(r -> gmpNumber(r) == gmpNumber("singular") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("feminine"), rules)
        if ! isempty(frules)
            generated = generate(lex, formurn(frules[1]),  kd)
            fform = join(generated,", ")
        end

        nform = ""
        nrules = filter(r -> gmpNumber(r) == gmpNumber("singular") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("neuter"), rules)
        if ! isempty(nrules)
            generated = generate(lex, formurn(nrules[1]),  kd)
            nform = join(generated,", ")
        end


       push!(lines, string("| **", labels[i], "** | ", mform, " | ", fform , " | ", nform, " |"))
    end
    push!(lines, "| *plural* |  |  |  |")
    for i in 1:length(labels)
        mform = ""
        mrules = filter(r -> gmpNumber(r) == gmpNumber("plural") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("masculine"), rules)
        if ! isempty(mrules)
            generated = generate(lex, formurn(mrules[1]),  kd)
            mform = join(generated,", ")
        end

        fform = ""
        frules = filter(r -> gmpNumber(r) == gmpNumber("plural") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("feminine"), rules)
        if ! isempty(frules)
            generated = generate(lex, formurn(frules[1]),  kd)
            fform = join(generated,", ")
        end

        nform = ""
        nrules = filter(r -> gmpNumber(r) == gmpNumber("plural") && gmpCase(r) == caselist[i] && gmpGender(r) == gmpGender("neuter"), rules)
        if ! isempty(nrules)
            generated = generate(lex, formurn(nrules[1]),  kd)
            nform = join(generated,", ")
        end


       push!(lines, string("| **", labels[i], "** | ", mform, " | ", fform , " | ", nform, " |"))
    end




    join(lines,"\n")
end
